Function dharitri_codec::top_encode_no_err
source · pub fn top_encode_no_err<T: TopEncodeNoErr>(obj: &T) -> Vec<u8>Expand description
Quick encoding of a type that never fails on encoding.
pub fn top_encode_no_err<T: TopEncodeNoErr>(obj: &T) -> Vec<u8>Quick encoding of a type that never fails on encoding.