Enum dharitri_codec::multi_types::OptionalValue
source · pub enum OptionalValue<T> {
Some(T),
None,
}Expand description
A smart contract argument or result that can be missing.
If arguments stop before this argument, None will be returned. As an endpoint result, the contract decides if it produces it or not.
As a principle, optional arguments or results should come last, otherwise there is ambiguity as to how to interpret what comes after.
Variants
Implementations
sourceimpl<T> OptionalValue<T>
impl<T> OptionalValue<T>
pub fn into_option(self) -> Option<T>