Functions

  • Calls both the fast exit and the regular dep-decode, compares that the outputs are equal, then returns the result. To be used in serialization tests.
  • Calls both the fast exit and the regular dep-encode, compares that the outputs are equal, then returns the result. To be used in serialization tests.
  • Calls both the fast exit and the regular top-decode, compares that the outputs are equal, then returns the result. To be used in serialization tests.
  • Calls both the fast exit and the regular top-encode, compares that the outputs are equal, then returns the result. To be used in serialization tests.
  • Calls dep_decode_or_exit and panics if an encoding error occurs. Do not use in smart contracts!
  • Calls dep_encode_or_exit and panics if an encoding error occurs. Do not use in smart contracts!
  • ser_deser_okDeprecated
    backwards compatibility only, will remove in next major release
  • Calls top_decode_or_exit and panics if an encoding error occurs. Do not use in smart contracts!
  • Calls top_encode_or_exit and panics if an encoding error occurs. Do not use in smart contracts!