pub trait TopEncodeNoErr: Sized {
    // Required method
    fn top_encode_no_err<O: TopEncodeOutput>(&self, output: O);
}
Most types will be encoded without any possibility of error. The trait is used to provide these implementations. This is currently not a substitute for implementing a proper TopEncode.

Required Methods

source

fn top_encode_no_err<O: TopEncodeOutput>(&self, output: O)

Object Safety

This trait is not object safe.

Implementations on Foreign Types

source

impl TopEncodeNoErr for bool

source

impl TopEncodeNoErr for i8

source

impl TopEncodeNoErr for i16

source

impl TopEncodeNoErr for i32

source

impl TopEncodeNoErr for i64

source

impl TopEncodeNoErr for isize

source

impl TopEncodeNoErr for u8

source

impl TopEncodeNoErr for u16

source

impl TopEncodeNoErr for u32

source

impl TopEncodeNoErr for u64

source

impl TopEncodeNoErr for usize

Implementors